@@ -15,10 +15,11 @@ sub _default_data {
 		#cmds=>{cmd1=>{a=>'c1',_sub=>sub { &cmdsCalled('cmd1') }},
 			cmd2=>{_sub=>sub { &cmdsCalled('cmd2');return 0 } }
 		},
-		lib=>{cmds=>[qw/libcmd/],
+		subs=>{blah=>{qw/id blah/}},
+		#lib=>{cmds=>[qw/libcmd/],
 			#not yet
 			#vars=>[qw/libvar/]
-		}
+			#}
 	}
 }
 our $called_tests;
@@ -26,4 +27,8 @@ sub t_testcmd { $called_tests++ ;return 1}
 my $obj = {};
 sub _initLib { $obj = $_[0] if ($_[0]); return $obj}
 sub cmdsCalled { push (@called_cmds,$_[0]) }
+#used by fry_sub
+our @use;
+sub import { @use = @_ };
+#*import = \&cmdsCalled;
 1;
